@@ -123,7 +123,7 @@ public abstract class AbstractDependencyMojo
     /**
      * Contains the full list of projects in the reactor.
      */
-    @Parameter( defaultValue = "${reactorProjects}" )
+    @Parameter( defaultValue = "${reactorProjects}", readonly = true )
     protected List<MavenProject> reactorProjects;
 
     /**
@@ -132,7 +132,7 @@ public abstract class AbstractDependencyMojo
      * @since 2.0
      */
     @Parameter( property = "silent", defaultValue = "false" )
-    public boolean silent;
+    protected boolean silent;
 
     /**
      * Output absolute filename for resolved artifacts
@@ -212,12 +212,11 @@ public abstract class AbstractDependencyMojo
     protected void copyFile( File artifact, File destFile )
         throws MojoExecutionException
     {
-        Log theLog = this.getLog();
         try
         {
-            theLog.info(
-                "Copying " + ( this.outputAbsoluteArtifactFilename ? artifact.getAbsolutePath() : artifact.getName() )
-                    + " to " + destFile );
+            getLog().info( "Copying "
+                               + ( this.outputAbsoluteArtifactFilename ? artifact.getAbsolutePath()
+                                               : artifact.getName() ) + " to " + destFile );
 
             if ( artifact.isDirectory() )
             {
@@ -282,7 +281,7 @@ public abstract class AbstractDependencyMojo
 
             unArchiver.setUseJvmChmod( useJvmChmod );
 
-            unArchiver.setIgnorePermissions( this.ignorePermissions );
+            unArchiver.setIgnorePermissions( ignorePermissions );
 
             unArchiver.setSourceFile( file );
 
@@ -402,7 +401,7 @@ public abstract class AbstractDependencyMojo
     /**
      * @return Returns the resolver.
      */
-    public org.apache.maven.artifact.resolver.ArtifactResolver getResolver()
+    public ArtifactResolver getResolver()
     {
         return this.resolver;
     }
