@@ -19,13 +19,7 @@ package org.apache.maven.plugin.dependency.fromConfiguration;
  * under the License.
  */
 
-import java.io.File;
-import java.util.Collections;
-import java.util.List;
-import java.util.Set;
-
 import org.apache.maven.artifact.Artifact;
-import org.apache.maven.artifact.ArtifactUtils;
 import org.apache.maven.artifact.repository.ArtifactRepository;
 import org.apache.maven.artifact.repository.ArtifactRepositoryFactory;
 import org.apache.maven.artifact.resolver.ArtifactNotFoundException;
@@ -34,104 +28,86 @@ import org.apache.maven.artifact.versioning.InvalidVersionSpecificationException
 import org.apache.maven.artifact.versioning.VersionRange;
 import org.apache.maven.model.Dependency;
 import org.apache.maven.plugin.MojoExecutionException;
+import org.apache.maven.plugin.MojoFailureException;
 import org.apache.maven.plugin.dependency.AbstractDependencyMojo;
 import org.apache.maven.plugin.dependency.utils.DependencyUtil;
 import org.apache.maven.plugin.dependency.utils.filters.ArtifactItemFilter;
+import org.apache.maven.plugins.annotations.Component;
+import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.project.MavenProject;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactFilterException;
-import org.codehaus.plexus.util.FileUtils;
 import org.codehaus.plexus.util.StringUtils;
 
+import java.io.File;
+import java.util.Collections;
+import java.util.List;
+import java.util.Set;
+
 /**
- * Abstract Parent class used by mojos that get Artifact information from the plugin configuration as an ArrayList of
+ * Abstract parent class used by mojos that get Artifact information from the plugin configuration as an ArrayList of
  * ArtifactItems
- * 
- * @see ArtifactItem
+ *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id: AbstractFromConfigurationMojo.java 1143035 2011-07-05 12:54:20Z stephenc $
+ * @version $Id: AbstractFromConfigurationMojo.java 1481555 2013-05-12 13:39:04Z hboutemy $
+ * @see ArtifactItem
  */
 public abstract class AbstractFromConfigurationMojo
     extends AbstractDependencyMojo
 {
     /**
-     * Skip the execution
-     * 
-     * @optional
-     * @since 2.2
-     * @parameter expression="${mdep.skip}" default-value="false"
-     */
-    private boolean skip;
-
-    /**
-     * Default location used for mojo unless overridden in ArtifactItem
-     * 
-     * @parameter expression="${outputDirectory}" default-value="${project.build.directory}/dependency"
-     * @optional
+     * Default output location used for mojo, unless overridden in ArtifactItem.
+     *
      * @since 1.0
      */
+    @Parameter( property = "outputDirectory", defaultValue = "${project.build.directory}/dependency" )
     private File outputDirectory;
 
     /**
      * Overwrite release artifacts
-     * 
-     * @optional
+     *
      * @since 1.0
-     * @parameter expression="${mdep.overWriteReleases}" default-value="false"
      */
+    @Parameter( property = "mdep.overWriteReleases", defaultValue = "false" )
     private boolean overWriteReleases;
 
     /**
      * Overwrite snapshot artifacts
-     * 
-     * @optional
+     *
      * @since 1.0
-     * @parameter expression="${mdep.overWriteSnapshots}" default-value="false"
      */
+    @Parameter( property = "mdep.overWriteSnapshots", defaultValue = "false" )
     private boolean overWriteSnapshots;
 
     /**
      * Overwrite if newer
-     * 
-     * @optional
+     *
      * @since 2.0
-     * @parameter expression="${mdep.overIfNewer}" default-value="true"
      */
+    @Parameter( property = "mdep.overIfNewer", defaultValue = "true" )
     private boolean overWriteIfNewer;
 
-    /**
-     * To search for artifacts within the reactor and ensure consistent behaviour between Maven 2 and Maven 3.
-     *
-     * @parameter expression="${reactorProjects}"
-     * @required
-     * @readonly
-     */
-    protected List<MavenProject> reactorProjects;
-
     /**
      * Collection of ArtifactItems to work on. (ArtifactItem contains groupId, artifactId, version, type, classifier,
-     * location, destFileName, markerFile and overwrite.) See <a href="./usage.html">Usage</a> for details.
-     * 
-     * @parameter
-     * @required
+     * outputDirectory, destFileName and overWrite.) See <a href="./usage.html">Usage</a> for details.
+     *
      * @since 1.0
      */
+    @Parameter
     private List<ArtifactItem> artifactItems;
 
     /**
      * To look up ArtifactRepository implementation
-     * 
-     * @component
-     * @readonly
      */
+    @Component
     private ArtifactRepositoryFactory artifactRepositoryManager;
 
     /**
      * Path to override default local repository during plugin's execution. To remove all downloaded artifacts as part
      * of the build, set this value to a location under your project's target directory
-     * 
-     * @parameter
+     *
      * @since 2.2
      */
+    @Parameter
     private File localRepositoryDirectory;
 
     /**
@@ -140,19 +116,37 @@ public abstract class AbstractFromConfigurationMojo
     private ArtifactRepository overrideLocalRepository;
 
     abstract ArtifactItemFilter getMarkedArtifactFilter( ArtifactItem item );
+    
+    // artifactItems is filled by either field injection or by setArtifact()
+    protected void verifyRequirements() throws MojoFailureException
+    {
+        if ( artifactItems == null || artifactItems.isEmpty() )
+        {
+            throw new MojoFailureException( "Either artifact or artifactItems is required " );
+        }
+    }
 
     /**
      * Preprocesses the list of ArtifactItems. This method defaults the outputDirectory if not set and creates the
      * output Directory if it doesn't exist.
-     * 
+     *
      * @param removeVersion remove the version from the filename.
+     * @param prependGroupId prepend the groupId to the filename.
+     * @param useBaseVersion use the baseVersion of the artifact instead of version for the filename.
      * @return An ArrayList of preprocessed ArtifactItems
      * @throws MojoExecutionException with a message if an error occurs.
      * @see ArtifactItem
      */
-    protected List<ArtifactItem> getProcessedArtifactItems( boolean removeVersion )
+    protected List<ArtifactItem> getProcessedArtifactItems( ProcessArtifactItemsRequest processArtifactItemsRequest  )
         throws MojoExecutionException
     {
+
+        boolean removeVersion = processArtifactItemsRequest.isRemoveVersion(), prependGroupId =
+            processArtifactItemsRequest.isPrependGroupId(), useBaseVersion =
+            processArtifactItemsRequest.isUseBaseVersion();
+        
+        boolean removeClassifier = processArtifactItemsRequest.isRemoveClassifier();
+
         if ( artifactItems == null || artifactItems.size() < 1 )
         {
             throw new MojoExecutionException( "There are no artifactItems configured." );
@@ -179,7 +173,8 @@ public abstract class AbstractFromConfigurationMojo
             if ( StringUtils.isEmpty( artifactItem.getDestFileName() ) )
             {
                 artifactItem.setDestFileName( DependencyUtil.getFormattedFileName( artifactItem.getArtifact(),
-                                                                                   removeVersion ) );
+                                                                                   removeVersion, prependGroupId,
+                                                                                   useBaseVersion, removeClassifier ) );
             }
 
             try
@@ -197,23 +192,14 @@ public abstract class AbstractFromConfigurationMojo
     private boolean checkIfProcessingNeeded( ArtifactItem item )
         throws MojoExecutionException, ArtifactFilterException
     {
-        boolean result = false;
-        if ( StringUtils.equalsIgnoreCase( item.getOverWrite(), "true" ) )
-        {
-            result = true;
-        }
-        else
-        {
-            ArtifactItemFilter filter = getMarkedArtifactFilter( item );
-            result = filter.isArtifactIncluded( item );
-        }
-        return result;
+        return StringUtils.equalsIgnoreCase( item.getOverWrite(), "true" )
+            || getMarkedArtifactFilter( item ).isArtifactIncluded( item );
     }
 
     /**
      * Resolves the Artifact from the remote repository if necessary. If no version is specified, it will be retrieved
      * from the dependency list or from the DependencyManagement section of the pom.
-     * 
+     *
      * @param artifactItem containing information about artifact from plugin configuration.
      * @return Artifact object representing the specified file.
      * @throws MojoExecutionException with a message if the version can't be found in DependencyManagement.
@@ -223,8 +209,7 @@ public abstract class AbstractFromConfigurationMojo
     {
         Artifact artifact;
 
-        // Map managedVersions = createManagedVersionMap( factory,
-        // project.getId(), project.getDependencyManagement() );
+        // Map managedVersions = createManagedVersionMap( factory, project.getId(), project.getDependencyManagement() );
         VersionRange vr;
         try
         {
@@ -239,16 +224,14 @@ public abstract class AbstractFromConfigurationMojo
 
         if ( StringUtils.isEmpty( artifactItem.getClassifier() ) )
         {
-            artifact =
-                factory.createDependencyArtifact( artifactItem.getGroupId(), artifactItem.getArtifactId(), vr,
-                                                  artifactItem.getType(), null, Artifact.SCOPE_COMPILE );
+            artifact = factory.createDependencyArtifact( artifactItem.getGroupId(), artifactItem.getArtifactId(), vr,
+                                                         artifactItem.getType(), null, Artifact.SCOPE_COMPILE );
         }
         else
         {
-            artifact =
-                factory.createDependencyArtifact( artifactItem.getGroupId(), artifactItem.getArtifactId(), vr,
-                                                  artifactItem.getType(), artifactItem.getClassifier(),
-                                                  Artifact.SCOPE_COMPILE );
+            artifact = factory.createDependencyArtifact( artifactItem.getGroupId(), artifactItem.getArtifactId(), vr,
+                                                         artifactItem.getType(), artifactItem.getClassifier(),
+                                                         Artifact.SCOPE_COMPILE );
         }
 
         // Maven 3 will search the reactor for the artifact but Maven 2 does not
@@ -258,6 +241,7 @@ public abstract class AbstractFromConfigurationMojo
         {
             return result;
         }
+
         try
         {
             // mdep-50 - rolledback for now because it's breaking some functionality.
@@ -286,9 +270,10 @@ public abstract class AbstractFromConfigurationMojo
 
     /**
      * Checks to see if the specified artifact is available from the reactor.
+     *
      * @param artifact The artifact we are looking for.
      * @return The resolved artifact that is the same as the one we were looking for or <code>null</code> if one could
-     * not be found.
+     *         not be found.
      */
     private Artifact getArtifactFomReactor( Artifact artifact )
     {
@@ -300,6 +285,7 @@ public abstract class AbstractFromConfigurationMojo
                 return a;
             }
         }
+
         // check reactor projects
         for ( MavenProject p : reactorProjects == null ? Collections.<MavenProject>emptyList() : reactorProjects )
         {
@@ -308,6 +294,7 @@ public abstract class AbstractFromConfigurationMojo
             {
                 return p.getArtifact();
             }
+
             // check any side artifacts
             for ( Artifact a : (List<Artifact>) p.getAttachedArtifacts() )
             {
@@ -317,12 +304,14 @@ public abstract class AbstractFromConfigurationMojo
                 }
             }
         }
+
         // not available
         return null;
     }
 
     /**
      * Returns <code>true</code> if the artifact has a file.
+     *
      * @param artifact the artifact (may be null)
      * @return <code>true</code> if and only if the artifact is non-null and has a file.
      */
@@ -333,15 +322,15 @@ public abstract class AbstractFromConfigurationMojo
 
     /**
      * Null-safe compare of two artifacts based on groupId, artifactId, version, type and classifier.
+     *
      * @param a the first artifact.
      * @param b the second artifact.
      * @return <code>true</code> if and only if the two artifacts have the same groupId, artifactId, version,
-     * type and classifier.
+     *         type and classifier.
      */
     private static boolean equals( Artifact a, Artifact b )
     {
-        return a == b
-            || !( a == null || b == null )
+        return a == b || !( a == null || b == null )
             && StringUtils.equals( a.getGroupId(), b.getGroupId() )
             && StringUtils.equals( a.getArtifactId(), b.getArtifactId() )
             && StringUtils.equals( a.getVersion(), b.getVersion() )
@@ -353,15 +342,15 @@ public abstract class AbstractFromConfigurationMojo
      * Tries to find missing version from dependency list and dependency management. If found, the artifact is updated
      * with the correct version. It will first look for an exact match on artifactId/groupId/classifier/type and if it
      * doesn't find a match, it will try again looking for artifactId and groupId only.
-     * 
+     *
      * @param artifact representing configured file.
      * @throws MojoExecutionException
      */
     private void fillMissingArtifactVersion( ArtifactItem artifact )
         throws MojoExecutionException
     {
-        List<Dependency> deps = project.getDependencies();
-        List<Dependency> depMngt = project.getDependencyManagement() == null
+        @SuppressWarnings( "unchecked" ) List<Dependency> deps = project.getDependencies();
+        @SuppressWarnings( "unchecked" ) List<Dependency> depMngt = project.getDependencyManagement() == null
             ? Collections.<Dependency>emptyList()
             : project.getDependencyManagement().getDependencies();
 
@@ -370,18 +359,19 @@ public abstract class AbstractFromConfigurationMojo
             && !findDependencyVersion( artifact, deps, true )
             && ( project.getDependencyManagement() == null || !findDependencyVersion( artifact, depMngt, true ) ) )
         {
-            throw new MojoExecutionException( "Unable to find artifact version of " + artifact.getGroupId() + ":"
-                + artifact.getArtifactId() + " in either dependency list or in project's dependency management." );
+            throw new MojoExecutionException(
+                "Unable to find artifact version of " + artifact.getGroupId() + ":" + artifact.getArtifactId()
+                    + " in either dependency list or in project's dependency management." );
         }
     }
 
     /**
      * Tries to find missing version from a list of dependencies. If found, the artifact is updated with the correct
      * version.
-     * 
-     * @param artifact representing configured file.
+     *
+     * @param artifact     representing configured file.
      * @param dependencies list of dependencies to search.
-     * @param looseMatch only look at artifactId and groupId
+     * @param looseMatch   only look at artifactId and groupId
      * @return the found dependency
      */
     private boolean findDependencyVersion( ArtifactItem artifact, List<Dependency> dependencies, boolean looseMatch )
@@ -416,7 +406,7 @@ public abstract class AbstractFromConfigurationMojo
 
     /**
      * Override the base to
-     * 
+     *
      * @return Returns the local.
      */
     protected ArtifactRepository getLocal()
@@ -531,13 +521,41 @@ public abstract class AbstractFromConfigurationMojo
         this.localRepositoryDirectory = localRepositoryDirectory;
     }
 
-    public boolean isSkip()
+    public void setArtifact( String artifact )
+        throws MojoFailureException
     {
-        return skip;
-    }
-
-    public void setSkip( boolean skip )
-    {
-        this.skip = skip;
+        if ( artifact != null )
+        {
+            String packaging = "jar";
+            String classifier;
+            String[] tokens = StringUtils.split( artifact, ":" );
+            if ( tokens.length < 3 || tokens.length > 5 )
+            {
+                throw new MojoFailureException(
+                    "Invalid artifact, you must specify groupId:artifactId:version[:packaging][:classifier] "
+                        + artifact );
+            }
+            String groupId = tokens[0];
+            String artifactId = tokens[1];
+            String version = tokens[2];
+            if ( tokens.length >= 4 )
+            {
+                packaging = tokens[3];
+            }
+            if ( tokens.length == 5 )
+            {
+                classifier = tokens[4];
+            }
+            else
+            {
+                classifier = null;
+            }
+    
+            Artifact toUnpack = classifier == null
+            ? factory.createBuildArtifact( groupId, artifactId, version, packaging )
+            : factory.createArtifactWithClassifier( groupId, artifactId, version, packaging, classifier );
+            
+            setArtifactItems( Collections.singletonList( new ArtifactItem( toUnpack ) ) );
+        }
     }
 }
