@@ -37,11 +37,11 @@ import java.util.List;
  * Goal that retrieves a list of artifacts from the repository and unpacks them in a defined location.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id: UnpackMojo.java 1451088 2013-02-28 04:22:41Z brianf $
+ * @version $Id: UnpackMojo.java 1481560 2013-05-12 14:03:49Z hboutemy $
  * @since 1.0
  */
 @Mojo( name = "unpack", defaultPhase = LifecyclePhase.PROCESS_SOURCES, requiresProject = false, threadSafe = true )
-public final class UnpackMojo
+public class UnpackMojo
     extends AbstractFromConfigurationMojo
 {
 
@@ -142,7 +142,7 @@ public final class UnpackMojo
         throws MojoExecutionException
     {
         List<ArtifactItem> items =
-            super.getProcessedArtifactItems( new ProcessArtifactItemsRequest( removeVersion, false, false ) );
+            super.getProcessedArtifactItems( new ProcessArtifactItemsRequest( removeVersion, false, false, false ) );
         for ( ArtifactItem artifactItem : items )
         {
             if ( StringUtils.isEmpty( artifactItem.getIncludes() ) )
