@@ -20,7 +20,6 @@ package org.apache.maven.plugin.dependency.resolvers;
  */
 
 import org.apache.maven.plugin.MojoExecutionException;
-import org.apache.maven.plugin.dependency.AbstractResolveMojo;
 import org.apache.maven.plugin.dependency.utils.DependencyStatusSets;
 import org.apache.maven.plugin.dependency.utils.DependencyUtil;
 import org.apache.maven.plugin.dependency.utils.filters.ResolveFileFilter;
@@ -37,7 +36,7 @@ import java.io.IOException;
  * Goal that resolves the project dependencies from the repository.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id: ResolveDependenciesMojo.java 1451088 2013-02-28 04:22:41Z brianf $
+ * @version $Id: ResolveDependenciesMojo.java 1482616 2013-05-14 22:08:15Z hboutemy $
  * @since 2.0
  */
 @Mojo( name = "resolve", requiresDependencyResolution = ResolutionScope.TEST,
@@ -59,6 +58,23 @@ public class ResolveDependenciesMojo
      */
     DependencyStatusSets results;
 
+    /**
+     * Sort the output list of resolved artifacts alphabetically.
+     * The default ordering matches the classpath order.
+     * 
+     * @since 2.8
+     */
+    @Parameter( property = "sort", defaultValue = "false" )
+    boolean sort;
+
+    /**
+     * Include parent poms in the dependency resolution list.
+     * 
+     * @since 2.8
+     */
+    @Parameter( property = "includeParents", defaultValue = "false" )
+    boolean includeParents;
+
     /**
      * Main entry into mojo. Gets the list of dependencies and iterates through displaying the resolved version.
      *
@@ -68,9 +84,9 @@ public class ResolveDependenciesMojo
         throws MojoExecutionException
     {
         // get sets of dependencies
-        results = this.getDependencySets( false );
+        results = this.getDependencySets( false, includeParents );
 
-        String output = results.getOutput( outputAbsoluteArtifactFilename, outputScope );
+        String output = results.getOutput( outputAbsoluteArtifactFilename, outputScope, sort );
         try
         {
             if ( outputFile == null )
