@@ -31,7 +31,6 @@ import org.apache.maven.artifact.repository.ArtifactRepository;
 import org.apache.maven.artifact.resolver.ArtifactNotFoundException;
 import org.apache.maven.artifact.resolver.ArtifactResolutionException;
 import org.apache.maven.plugin.MojoExecutionException;
-import org.apache.maven.plugin.dependency.AbstractResolveMojo;
 import org.apache.maven.plugin.dependency.utils.DependencyUtil;
 import org.apache.maven.plugins.annotations.LifecyclePhase;
 import org.apache.maven.plugins.annotations.Mojo;
@@ -47,7 +46,7 @@ import org.codehaus.plexus.util.IOUtil;
  * Goal that resolves all project plugins and reports and their dependencies.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id: ResolvePluginsMojo.java 1451088 2013-02-28 04:22:41Z brianf $
+ * @version $Id: ResolvePluginsMojo.java 1481553 2013-05-12 13:25:34Z hboutemy $
  * @since 2.0
  */
 @Mojo( name = "resolve-plugins", defaultPhase = LifecyclePhase.GENERATE_SOURCES, threadSafe = true )
@@ -95,8 +94,7 @@ public class ResolvePluginsMojo
                 String logStr = "Plugin Resolved: " + DependencyUtil.getFormattedFileName( plugin, false );
                 if ( !silent )
                 {
-                    this.getLog()
-                        .info( logStr );
+                    this.getLog().info( logStr );
                 }
 
                 if ( outputWriter != null )
@@ -114,8 +112,7 @@ public class ResolvePluginsMojo
 
                         if ( !silent )
                         {
-                            this.getLog()
-                                .info( logStr );
+                            this.getLog().info( logStr );
                         }
 
                         if ( outputWriter != null )
