@@ -34,7 +34,7 @@ import org.codehaus.plexus.util.StringUtils;
  * Utility class with static helper methods
  * 
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id: DependencyUtil.java 1399024 2012-10-16 22:23:33Z hboutemy $
+ * @version $Id: DependencyUtil.java 1481559 2013-05-12 14:01:17Z hboutemy $
  */
 public final class DependencyUtil
 {
@@ -90,8 +90,33 @@ public final class DependencyUtil
      * @return Formatted file name in the format
      *         [groupId].artifactId-[version]-[classifier].[type]
      */
+    public static String getFormattedFileName( Artifact artifact, boolean removeVersion, boolean prependGroupId,
+                                               boolean useBaseVersion )
+    {
+        return getFormattedFileName( artifact, removeVersion, prependGroupId, useBaseVersion, false );
+    }
+
+    /**
+     * Builds the file name. If removeVersion is set, then the file name must be
+     * reconstructed from the groupId (if <b>prependGroupId</b> is true) artifactId,
+     * Classifier (if used) and Type.
+     * Otherwise, this method returns the artifact file name.
+     * 
+     * @param artifact
+     *            File to be formatted.
+     * @param removeVersion
+     *            Specifies if the version should be removed from the file name.
+     * @param prependGroupId
+     *            Specifies if the groupId should be prepended to the file name.
+     * @param useBaseVersion
+     *            Specifies if the baseVersion of the artifact should be used instead of the version.
+     * @param removeClassifier
+     *            Specifies if the classifier of the artifact should be remved from the file name.
+     * @return Formatted file name in the format
+     *         [groupId].artifactId-[version]-[classifier].[type]
+     */
     public static String getFormattedFileName( Artifact artifact, boolean removeVersion, boolean prependGroupId, 
-    		boolean useBaseVersion )
+            boolean useBaseVersion, boolean removeClassifier )
     {
         StringBuilder destFileName = new StringBuilder();
         
@@ -119,7 +144,7 @@ public final class DependencyUtil
 
         String classifierString = "";
 
-        if ( StringUtils.isNotEmpty( artifact.getClassifier() ) )
+        if ( !removeClassifier && StringUtils.isNotEmpty( artifact.getClassifier() ) )
         {
             classifierString = "-" + artifact.getClassifier();
         }
@@ -129,7 +154,7 @@ public final class DependencyUtil
         
         return destFileName.toString();
     }
-
+    
     /**
      * Formats the outputDirectory based on type.
      * 
@@ -181,30 +206,27 @@ public final class DependencyUtil
 
         sb.append( artifact.getArtifactId() );
 
+        if ( !removeVersion )
+        {
+            sb.append( "-" );
+            sb.append( artifact.getVersion() );
+        }
+
         if ( StringUtils.isNotEmpty( artifact.getClassifier() ) )
         {
             sb.append( "-" );
             sb.append( artifact.getClassifier() );
         }
 
-        if ( !removeVersion )
+        // if the classifier and type are the same (sources), then don't
+        // repeat.
+        // avoids names like foo-sources-sources
+        if ( !StringUtils.equals( artifact.getClassifier(), artifact.getType() ) )
         {
-            sb.append( "-" );
-            sb.append( artifact.getVersion() );
             sb.append( "-" );
             sb.append( artifact.getType() );
         }
-        else
-        {
-            // if the classifier and type are the same (sources), then don't
-            // repeat.
-            // avoids names like foo-sources-sources
-            if ( !StringUtils.equals( artifact.getClassifier(), artifact.getType() ) )
-            {
-                sb.append( "-" );
-                sb.append( artifact.getType() );
-            }
-        }
+
         return sb.toString();
     }
 
