@@ -32,7 +32,7 @@ import org.codehaus.plexus.util.StringUtils;
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id: DestFileFilter.java 1367274 2012-07-30 20:32:05Z hboutemy $
+ * @version $Id: DestFileFilter.java 1463473 2013-04-02 10:28:02Z olamy $
  */
 public class DestFileFilter
     extends AbstractArtifactsFilter
@@ -53,6 +53,8 @@ public class DestFileFilter
     private boolean useRepositoryLayout;
 
     private boolean removeVersion;
+    
+    private boolean removeClassifier;
 
     private File outputFileDirectory;
 
@@ -66,6 +68,7 @@ public class DestFileFilter
         useSubDirectoryPerType = false;
         useSubDirectoryPerScope = false;
         removeVersion = false;
+        removeClassifier = false;
     }
 
     public DestFileFilter( boolean overWriteReleases, boolean overWriteSnapshots, boolean overWriteIfNewer,
@@ -190,6 +193,23 @@ public class DestFileFilter
     {
         this.removeVersion = removeVersion;
     }
+    
+    /**
+     * @return Returns the removeClassifier.
+     */
+    public boolean isRemoveClassifier()
+    {
+        return this.removeClassifier;
+    }
+
+    /**
+     * @param removeClassifier
+     *            The removeClassifier to set.
+     */
+    public void setRemoveClassifier( boolean removeClassifier )
+    {
+        this.removeClassifier = removeClassifier;
+    }
 
     /**
      * @return Returns the useSubDirectoryPerArtifact.
