@@ -59,7 +59,7 @@ public class TestUnpackMojo
         mojo = (UnpackMojo) lookupMojo( "unpack", testPom );
         mojo.setOutputDirectory( new File( this.testDir, "outputDirectory" ) );
         mojo.setMarkersDirectory( new File( this.testDir, "markers" ) );
-        mojo.silent = true;
+        setSilent( mojo, true );
 
         assertNotNull( mojo );
         assertNotNull( mojo.getProject() );
@@ -500,7 +500,7 @@ public class TestUnpackMojo
     {
         final long now = System.currentTimeMillis();
         
-        mojo.silent = false;
+        setSilent( mojo, false );
         stubFactory.setCreateFiles( true );
         Artifact artifact = stubFactory.getSnapshotArtifact();
         assertTrue( artifact.getFile().setLastModified( now - 20000 ) );
