@@ -157,6 +157,8 @@ public class DependencyProjectStub
     private String defaultGoal;
 
     private Set artifacts;
+    
+    private Properties properties;
 
     public DependencyProjectStub()
     {
@@ -228,14 +230,7 @@ public class DependencyProjectStub
 
     public boolean hasParent()
     {
-        if ( parent != null )
-        {
-            return true;
-        }
-        else
-        {
-            return false;
-        }
+        return ( parent != null );
     }
 
     public File getFile()
@@ -1010,7 +1005,11 @@ public class DependencyProjectStub
 
     public Properties getProperties()
     {
-        return new Properties();
+        if ( properties == null )
+        {
+            properties = new Properties();
+        }
+        return properties;
     }
 
     public List getFilters()
