@@ -118,7 +118,7 @@ public class TestDependencyUtil
         assertTrue( expectedResult.equalsIgnoreCase( name.getAbsolutePath() ) );
 
         name = DependencyUtil.getFormattedOutputDirectory( false, false, true, false, false, folder, artifact );
-        expectedResult = folder.getAbsolutePath() + File.separatorChar + "one-sources-1.1-jar";
+        expectedResult = folder.getAbsolutePath() + File.separatorChar + "one-1.1-sources-jar";
         assertEquals( expectedResult, name.getAbsolutePath() );
 
         name = DependencyUtil.getFormattedOutputDirectory( false, false, true, false, true, folder, artifact );
@@ -127,7 +127,7 @@ public class TestDependencyUtil
 
         name = DependencyUtil.getFormattedOutputDirectory( false, true, true, false, false, folder, artifact );
         expectedResult = folder.getAbsolutePath() + File.separatorChar + "jars" + File.separatorChar
-            + "one-sources-1.1-jar";
+            + "one-1.1-sources-jar";
         assertEquals( expectedResult, name.getAbsolutePath() );
 
         name = DependencyUtil.getFormattedOutputDirectory( false, true, true, false, true, folder, artifact );
@@ -186,7 +186,7 @@ public class TestDependencyUtil
         assertEquals( expectedResult, name.getAbsolutePath() );
 
         name = DependencyUtil.getFormattedOutputDirectory( false, false, true, false, false, folder, sources );
-        expectedResult = folder.getAbsolutePath() + File.separatorChar + "two-sources-1.1-SNAPSHOT-sources";
+        expectedResult = folder.getAbsolutePath() + File.separatorChar + "two-1.1-SNAPSHOT-sources";
         assertEquals( expectedResult, name.getAbsolutePath() );
     }
 
@@ -244,13 +244,16 @@ public class TestDependencyUtil
         name = DependencyUtil.getFormattedFileName( artifact, true );
         expectedResult = "two-sources.jar";
         assertEquals( expectedResult, name );
-
+        
+        name = DependencyUtil.getFormattedFileName(artifact, false, false, false, true);
+        expectedResult = "two-1.1-SNAPSHOT.jar";
+        assertEquals( expectedResult, name );
+        
         ah = new DefaultArtifactHandlerStub( "war", null );
         artifact = new DefaultArtifact( "test", "two", vr, Artifact.SCOPE_PROVIDED, "war", "", ah, false );
         name = DependencyUtil.getFormattedFileName( artifact, true );
         expectedResult = "two.war";
         assertEquals( expectedResult, name );
-
     }
 
     public void testFileNameClassifierWithFile()
@@ -271,10 +274,14 @@ public class TestDependencyUtil
         String expectedResult = "two-1.1-SNAPSHOT-sources.war";
         assertEquals( expectedResult, name );
 
+        name = DependencyUtil.getFormattedFileName( artifact, false, false, false, true );
+        expectedResult = "two-1.1-SNAPSHOT.war";
+        assertEquals( expectedResult, name );
+        
         name = DependencyUtil.getFormattedFileName( artifact, true );
         expectedResult = "two-sources.war";
         assertEquals( expectedResult, name );
-
+        
         artifact = new DefaultArtifact( "test", "two", vr, Artifact.SCOPE_PROVIDED, "war", "", ah, false );
         name = DependencyUtil.getFormattedFileName( artifact, true );
         expectedResult = "two.war";
